Tools to help studying the greek new testament. The crate is provided AS-IS.
Examples
use gnt_tools::core_char;
let s = "16 Εἶπεν δὲ παραβολὴν πρὸς αὐτοὺς λέγων·
ἀνθρώπου τινὸς πλουσίου εὐφόρησεν ἡ χώρα. 17
καὶ διελογίζετο ἐν ἑαυτῷ λέγων· τί ποιήσω, ὅτι
οὐκ ἔχω ποῦ συνάξω τοὺς καρπούς μου; ";
let s2 = "ειπενδεπαραβοληνπροϲαυτουϲλεγωνανθρωπουτ\
ινοϲπλουϲιουευφορηϲενηχωρακαιδιελογιζετοενεαυτω\
λεγωντιποιηϲωοτιουκεχωπουϲυναξωτουϲκαρπουϲμου";
let core_text : String = s.chars()
.filter_map(|c| core_char(&c))
.collect();
assert_eq!(core_text.as_str(), s2);Functions
- core_
char - The function helps giving the core text of a greek new testament critical edition.
This might be useful for comparing greek new testament critical editions by gettig their “core” differences/concordances.